/*
 * Copyright Fastly, Inc.
 * Licensed under the MIT license. See LICENSE file for details.
 */
import commandLineArgs from 'command-line-args';
const helpOptionsDefs = [
    { name: 'help', alias: 'h', type: Boolean },
];
export function isHelpArgs(argv) {
    const helpOptions = commandLineArgs(helpOptionsDefs, { argv, stopAtFirstUnknown: true });
    return !!helpOptions['help'];
}
export function findMainCommandNameAndArgs(argv) {
    const mainDefinitions = [
        { name: 'command', type: String, defaultOption: true },
    ];
    const mainOptions = commandLineArgs(mainDefinitions, { argv, stopAtFirstUnknown: true });
    const commandArgs = mainOptions._unknown || [];
    const command = mainOptions['command'];
    if (typeof command !== 'string') {
        return [null, commandArgs];
    }
    return [command, commandArgs];
}
export function getCommandAndArgs(argv, actions) {
    if (isHelpArgs(argv)) {
        return {
            needHelp: true,
            command: null,
        };
    }
    const result = findMainCommandNameAndArgs(argv);
    const [command, actionArgv] = result;
    if (command != null) {
        for (const modeName of Object.keys(actions)) {
            if (command === modeName) {
                return {
                    needHelp: false,
                    command: command,
                    argv: actionArgv,
                };
            }
        }
    }
    try {
        commandLineArgs([], { argv: actionArgv });
    }
    catch (err) {
        console.log(String(err));
    }
    return {
        needHelp: true,
        command,
    };
}
export function parseCommandLine(argv, optionDefinitions) {
    let commandLineOptions;
    try {
        commandLineOptions = commandLineArgs([
            ...helpOptionsDefs,
            ...optionDefinitions,
        ], { argv });
    }
    catch (err) {
        const error = err instanceof Error ? err : new Error(String(err));
        return {
            needHelp: true,
            error,
        };
    }
    if (!!commandLineOptions['help']) {
        return {
            needHelp: true,
            error: null,
        };
    }
    return {
        needHelp: false,
        commandLineOptions,
    };
}
